==> hledger-1.4-1-i686.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.4
id: hledger-1.4-Gi2jUbiMGO9H8X9FN6NQWr
key: hledger-1.4-Gi2jUbiMGO9H8X9FN6NQWr
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Equity
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.DocFiles Hledger.Cli.Main Hledger.Cli.Utils
    Hledger.Cli.Version Text.Tabular.AsciiWide
hidden-modules: Paths_hledger
abi: a4c5cda0b8c6a76c7df4b4c3af77b0d0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-1.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.4-Gi2jUbiMGO9H8X9FN6NQWr
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU directory-1.3.0.2
    file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor filepath-1.4.1.2
    here-1.2.11-7oDOz8L1Ula2z3e5ZeDko8
    pretty-show-1.6.13-1Y3SqFKPaj5ELeEKE7rREK process-1.6.1.0
    shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    tabular-0.2.2.7-H6HQxZw1kjr7chsimRmSHU time-1.8.0.2
    utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj
    hledger-lib-1.4-6P8oShydK9J3djtUIdqOY8 bytestring-0.10.8.2
    containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
    csv-0.1.2-FTLnfLeG7H17CWj1kGbhS5
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    Diff-0.3.4-9Jk7nn49ORI32Gqvs1rQQi
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk haskeline-0.7.4.0
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj transformers-0.5.2.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    wizards-1.0.2-ZspRevRBIDHbopg40X3g1 terminfo-0.4.1.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor=4c4a179f38ff188758c3889c26e3ca23
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             here-1.2.11-7oDOz8L1Ula2z3e5ZeDko8=071c83a3058bf8db37adb3b97beeff3a
             pretty-show-1.6.13-1Y3SqFKPaj5ELeEKE7rREK=3cf13d563b1d9ee00d8081a6c5d9ee2c
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk=c1be0c7e3aef06708629b91f4c947edf
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             tabular-0.2.2.7-H6HQxZw1kjr7chsimRmSHU=56ecd79702e8555ed1311007f33ae75d
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj=1a1809eb8ba2e75eb9ba0f6b65f67465
             hledger-lib-1.4-6P8oShydK9J3djtUIdqOY8=a8f7e0f1dde4a1a33899fd0a9b400165
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf=7dc5ecfdbaee81800275945c72ee928b
             csv-0.1.2-FTLnfLeG7H17CWj1kGbhS5=e7c836e2b810deed356ddc35bd7fb6ec
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             Diff-0.3.4-9Jk7nn49ORI32Gqvs1rQQi=4a076f7d412b78254830fa3a1e8b05a6
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             haskeline-0.7.4.0=ee72a1e6f6c246132a6260bcf7bd279e
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz=2b484d5ea1b9fe6449fe405f8626e332
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             wizards-1.0.2-ZspRevRBIDHbopg40X3g1=f0e4a4052ccd58875c7ea06f45ee7959
             terminfo-0.4.1.0=67e83cf79bca91cae06f86a540af75f6
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-1.4-2-i686.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.4
id: hledger-1.4-AIq6K1MP4hs3dKemNlmB5G
key: hledger-1.4-AIq6K1MP4hs3dKemNlmB5G
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Equity
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.DocFiles Hledger.Cli.Main Hledger.Cli.Utils
    Hledger.Cli.Version Text.Tabular.AsciiWide
hidden-modules: Paths_hledger
abi: dcc67fd9e369bf946ff44a3cf77f9693
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-1.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.4-AIq6K1MP4hs3dKemNlmB5G
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU directory-1.3.0.2
    file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor filepath-1.4.1.2
    here-1.2.11-7oDOz8L1Ula2z3e5ZeDko8
    pretty-show-1.6.13-1Y3SqFKPaj5ELeEKE7rREK process-1.6.1.0
    shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    tabular-0.2.2.7-H6HQxZw1kjr7chsimRmSHU time-1.8.0.2
    utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj
    hledger-lib-1.4-6P8oShydK9J3djtUIdqOY8 bytestring-0.10.8.2
    containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
    csv-0.1.2-FTLnfLeG7H17CWj1kGbhS5
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    Diff-0.3.4-9Jk7nn49ORI32Gqvs1rQQi
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk haskeline-0.7.4.0
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz
    regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj transformers-0.5.2.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    wizards-1.0.2-ZspRevRBIDHbopg40X3g1 terminfo-0.4.1.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor=4c4a179f38ff188758c3889c26e3ca23
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             here-1.2.11-7oDOz8L1Ula2z3e5ZeDko8=071c83a3058bf8db37adb3b97beeff3a
             pretty-show-1.6.13-1Y3SqFKPaj5ELeEKE7rREK=3cf13d563b1d9ee00d8081a6c5d9ee2c
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi=5b0146feaa47ba68d8065943ed5853bc
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             tabular-0.2.2.7-H6HQxZw1kjr7chsimRmSHU=56ecd79702e8555ed1311007f33ae75d
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj=1a1809eb8ba2e75eb9ba0f6b65f67465
             hledger-lib-1.4-6P8oShydK9J3djtUIdqOY8=a8f7e0f1dde4a1a33899fd0a9b400165
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf=7dc5ecfdbaee81800275945c72ee928b
             csv-0.1.2-FTLnfLeG7H17CWj1kGbhS5=e7c836e2b810deed356ddc35bd7fb6ec
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             Diff-0.3.4-9Jk7nn49ORI32Gqvs1rQQi=4a076f7d412b78254830fa3a1e8b05a6
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             haskeline-0.7.4.0=ee72a1e6f6c246132a6260bcf7bd279e
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz=2b484d5ea1b9fe6449fe405f8626e332
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             wizards-1.0.2-ZspRevRBIDHbopg40X3g1=f0e4a4052ccd58875c7ea06f45ee7959
             terminfo-0.4.1.0=67e83cf79bca91cae06f86a540af75f6
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
